[open-ils-commits] [GIT] Evergreen ILS branch master updated. f489194ee39bb59cad75d644f9fbe9d23c7a20e3

Evergreen Git git at git.evergreen-ils.org
Wed Aug 15 14:16:36 EDT 2012


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Evergreen ILS".

The branch, master has been updated
       via  f489194ee39bb59cad75d644f9fbe9d23c7a20e3 (commit)
      from  67502a510482fb9c3d101b2d1ccde96d1ed14e30 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit f489194ee39bb59cad75d644f9fbe9d23c7a20e3
Author: Thomas Berezansky <tsbere at mvlc.org>
Date:   Tue Jul 31 15:35:21 2012 -0400

    Check for filled hold on transit checkin
    
    "Fill related hold" can grab a hold out from under a transit, so check for
    filled holds in addition to canceled ones.
    
    Signed-off-by: Thomas Berezansky <tsbere at mvlc.org>
    Signed-off-by: Bill Erickson <berick at esilibrary.com>

diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Circulate.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Circulate.pm
index 262e0ba..83a46a8 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Circulate.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Circulate.pm
@@ -2588,9 +2588,9 @@ sub do_checkin {
 
             $self->hold($hold);
 
-            if( $hold and $hold->cancel_time ) { # this transited hold was cancelled mid-transit
+            if( $hold and ( $hold->cancel_time or $hold->fulfillment_time ) ) { # this transited hold was cancelled or filled mid-transit
 
-                $logger->info("circulator: we received a transit on a cancelled hold " . $hold->id);
+                $logger->info("circulator: we received a transit on a cancelled or filled hold " . $hold->id);
                 $self->reshelve_copy(1);
                 $self->cancelled_hold_transit(1);
                 $self->notify_hold(0); # don't notify for cancelled holds

-----------------------------------------------------------------------

Summary of changes:
 .../lib/OpenILS/Application/Circ/Circulate.pm      |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
Evergreen ILS


More information about the open-ils-commits mailing list